// --------------------------------------------
// (c) Copyright National Instruments 2009-2022
// All rights reserved.
// --------------------------------------------

#ifndef NIDIAGCS_H
#define NIDIAGCS_H

#include "nidiagcs_extcode.h"
#define __stdcall
#define __cdecl

#ifdef __cplusplus
extern "C" {
#endif
typedef struct {
	int32_t DiagCANHandle;
	uint16_t TransportProtocol;
	uint8_t ReceiveAddressExtension;
	uint8_t TransmitAddressExtension;
	uint8_t Reserved1;
	uint8_t Reserved2;
	} TD1;

typedef struct {
	int32_t StartByte;
	int32_t ByteLength;
	uint16_t ByteOrder;
	uint16_t DataType;
	double ScaleFactor;
	double ScaleOffset;
	} TD2;

typedef struct {
	int32_t DTCByteLength;
	int32_t StatusByteLength;
	int32_t AddDataByteLength;
	uint16_t ByteOrder;
	} TD3;

typedef struct {
	uint32_t DTC;
	uint32_t Status;
	uint32_t AddData;
	} TD4;

typedef struct {
	uint32_t SPN;
	uint32_t Status;
	uint32_t AddData;
	uint32_t FMI;
	} TD5;

typedef struct {
	uint16_t DTC;
	uint8_t FTB;
	uint32_t Status;
	uint32_t AddData;
	} TD6;


/*!
 * ndCloseDiagnostic
 */
int32_t __cdecl ndCloseDiagnostic(TD1 *diagRef);
/*!
 * ndConvertFromPhys
 */
void __cdecl ndConvertFromPhys(TD2 *typeDescriptor, double value, 
	uint8_t dataOut[], int32_t *len);
/*!
 * ndConvertToPhys
 */
void __cdecl ndConvertToPhys(TD2 *typeDescriptor, uint8_t dataIn[], 
	int32_t len, double *value);
/*!
 * ndDiagnosticService
 */
int32_t __cdecl ndDiagnosticService(TD1 *diagRef, LVBoolean *requireResponse, 
	uint8_t dataIn[], int32_t len, uint8_t dataOut[], int32_t *len2);
/*!
 * ndDisableNormalMessageTransmission
 */
int32_t __cdecl ndDisableNormalMessageTransmission(TD1 *diagRef, 
	LVBoolean *requireResponse, LVBoolean *success);
/*!
 * ndDTCToString
 */
void __cdecl ndDTCToString(uint32_t DTCNum, char DTCString[], int32_t *len);
/*!
 * ndECUReset
 */
int32_t __cdecl ndECUReset(TD1 *diagRef, uint8_t mode, LVBoolean *success);
/*!
 * ndEnableNormalMessageTransmission
 */
int32_t __cdecl ndEnableNormalMessageTransmission(TD1 *diagRef, 
	LVBoolean *requireResponse, LVBoolean *success);
/*!
 * ndInputOutputControlByLocalIdentifier
 */
int32_t __cdecl ndInputOutputControlByLocalIdentifier(TD1 *diagRef, 
	uint8_t localID, uint8_t mode, uint8_t dataIn[], int32_t len, 
	uint8_t dataOut[], int32_t *len2, LVBoolean *success);
/*!
 * ndOBDClearEmissionRelatedDiagnosticInformation
 */
int32_t __cdecl ndOBDClearEmissionRelatedDiagnosticInformation(TD1 *diagRef, 
	LVBoolean *success);
/*!
 * ndOBDRequestControlOfOnBoardDevice
 */
int32_t __cdecl ndOBDRequestControlOfOnBoardDevice(TD1 *diagRef, uint8_t TID, 
	uint8_t dataIn[], int32_t len, uint8_t dataOut[], int32_t *len2, 
	LVBoolean *success);
/*!
 * ndOBDRequestCurrentPowertrainDiagnosticData
 */
int32_t __cdecl ndOBDRequestCurrentPowertrainDiagnosticData(TD1 *diagRef, 
	uint8_t PID, uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndOBDRequestEmissionRelatedDTCs
 */
int32_t __cdecl ndOBDRequestEmissionRelatedDTCs(TD1 *diagRef, 
	TD3 *DTCDescriptor, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndOBDRequestEmissionRelatedDTCsDuringCurrentDriveCycle
 */
int32_t __cdecl ndOBDRequestEmissionRelatedDTCsDuringCurrentDriveCycle(
	TD1 *diagRef, TD3 *DTCDescriptor, TD4 DTCs[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndOBDRequestOnBoardMonitoringTestResults
 */
int32_t __cdecl ndOBDRequestOnBoardMonitoringTestResults(TD1 *diagRef, 
	uint8_t OBDMID, uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndOBDRequestPermanentFaultCodes
 */
int32_t __cdecl ndOBDRequestPermanentFaultCodes(TD1 *diagRef, 
	TD3 *DTCDescriptor, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndOBDRequestPowertrainFreezeFrameData
 */
int32_t __cdecl ndOBDRequestPowertrainFreezeFrameData(TD1 *diagRef, 
	uint8_t PID, uint8_t frame, uint8_t dataOut[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndOBDRequestVehicleInformation
 */
int32_t __cdecl ndOBDRequestVehicleInformation(TD1 *diagRef, 
	uint8_t infoType, uint8_t *items, uint8_t dataOut[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndOpenDiagnostic
 */
int32_t __cdecl ndOpenDiagnostic(char CANInterface[], uint32_t baudrate, 
	uint16_t transportProtocol, uint32_t transmitID, uint32_t receiveID, 
	TD1 *diagRefOut);
/*!
 * ndReadDataByLocalIdentifier
 */
int32_t __cdecl ndReadDataByLocalIdentifier(TD1 *diagRef, uint8_t localID, 
	uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndReadDTCByStatus
 */
int32_t __cdecl ndReadDTCByStatus(TD1 *diagRef, uint8_t mode, 
	uint16_t groupOfDTC, TD3 *DTCDescriptor, TD4 DTCs[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndReadECUIdentification
 */
int32_t __cdecl ndReadECUIdentification(TD1 *diagRef, uint8_t mode, 
	uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndReadMemoryByAddress
 */
int32_t __cdecl ndReadMemoryByAddress(TD1 *diagRef, uint32_t address, 
	uint8_t size, uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndReadStatusOfDTC
 */
int32_t __cdecl ndReadStatusOfDTC(TD1 *diagRef, uint16_t groupOfDTC, 
	TD3 *DTCDescriptor, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndRequestRoutineResultsByLocalIdentifier
 */
int32_t __cdecl ndRequestRoutineResultsByLocalIdentifier(TD1 *diagRef, 
	uint8_t localID, uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndRequestSeed
 */
int32_t __cdecl ndRequestSeed(TD1 *diagRef, uint8_t accessMode, 
	uint8_t seedOut[], int32_t *len, LVBoolean *success);
/*!
 * ndSendKey
 */
int32_t __cdecl ndSendKey(TD1 *diagRef, uint8_t accessMode, uint8_t keyIn[], 
	int32_t len, LVBoolean *success);
/*!
 * ndStartDiagnosticSession
 */
int32_t __cdecl ndStartDiagnosticSession(TD1 *diagRef, uint8_t mode, 
	LVBoolean *success);
/*!
 * ndStartRoutineByLocalIdentifier
 */
int32_t __cdecl ndStartRoutineByLocalIdentifier(TD1 *diagRef, 
	uint8_t localID, uint8_t dataIn[], int32_t len, uint8_t dataOut[], 
	int32_t *len2, LVBoolean *success);
/*!
 * ndStatusToString
 */
void __cdecl ndStatusToString(int32_t errorCode, char message[], 
	int32_t *len);
/*!
 * ndStopDiagnosticSession
 */
int32_t __cdecl ndStopDiagnosticSession(TD1 *diagRef, LVBoolean *success);
/*!
 * ndStopRoutineByLocalIdentifier
 */
int32_t __cdecl ndStopRoutineByLocalIdentifier(TD1 *diagRef, uint8_t localID, 
	uint8_t dataIn[], int32_t len, uint8_t dataOut[], int32_t *len2, 
	LVBoolean *success);
/*!
 * ndTesterPresent
 */
int32_t __cdecl ndTesterPresent(TD1 *diagRef, LVBoolean *responseRequired, 
	LVBoolean *success);
/*!
 * ndUDSCommunicationControl
 */
int32_t __cdecl ndUDSCommunicationControl(TD1 *diagRef, uint8_t type, 
	uint8_t communicationType, LVBoolean *success);
/*!
 * ndUDSControlDTCSetting
 */
int32_t __cdecl ndUDSControlDTCSetting(TD1 *diagRef, uint8_t type, 
	uint8_t dataIn[], int32_t len, LVBoolean *success);
/*!
 * ndUDSDiagnosticSessionControl
 */
int32_t __cdecl ndUDSDiagnosticSessionControl(TD1 *diagRef, uint8_t mode, 
	LVBoolean *success);
/*!
 * ndUDSECUReset
 */
int32_t __cdecl ndUDSECUReset(TD1 *diagRef, uint8_t mode, LVBoolean *success);
/*!
 * ndUDSInputOutputControlByIdentifier
 */
int32_t __cdecl ndUDSInputOutputControlByIdentifier(TD1 *diagRef, 
	uint16_t ID, uint8_t mode, uint8_t dataIn[], int32_t len, uint8_t dataOut[], 
	int32_t *len2, LVBoolean *success);
/*!
 * ndUDSReadDataByIdentifier
 */
int32_t __cdecl ndUDSReadDataByIdentifier(TD1 *diagRef, uint16_t ID, 
	uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSReadMemoryByAddress
 */
int32_t __cdecl ndUDSReadMemoryByAddress(TD1 *diagRef, uint32_t address, 
	uint8_t size, uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSReportDTCBySeverityMaskRecord
 */
int32_t __cdecl ndUDSReportDTCBySeverityMaskRecord(TD1 *diagRef, 
	uint8_t severityMask, uint8_t status, TD3 *DTCDescriptor, 
	uint8_t *statusAvailMask, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSReportDTCByStatusMask
 */
int32_t __cdecl ndUDSReportDTCByStatusMask(TD1 *diagRef, uint8_t statusMask, 
	TD3 *DTCDescriptor, uint8_t *statusAvailMask, TD4 DTCs[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndUDSReportSeverityInformationOfDTC
 */
int32_t __cdecl ndUDSReportSeverityInformationOfDTC(TD1 *diagRef, 
	uint32_t DTCMaskRecord, TD3 *DTCDescriptor, uint8_t *statusAvailMask, 
	TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSReportSupportedDTCs
 */
int32_t __cdecl ndUDSReportSupportedDTCs(TD1 *diagRef, TD3 *DTCDescriptor, 
	uint8_t *statusAvailMask, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSRequestSeed
 */
int32_t __cdecl ndUDSRequestSeed(TD1 *diagRef, uint8_t accessMode, 
	uint8_t seedOut[], int32_t *len, LVBoolean *success);
/*!
 * ndUDSRoutineControl
 */
int32_t __cdecl ndUDSRoutineControl(TD1 *diagRef, uint16_t ID, uint8_t mode, 
	uint8_t dataIn[], int32_t len, uint8_t dataOut[], int32_t *len2, 
	LVBoolean *success);
/*!
 * ndUDSSendKey
 */
int32_t __cdecl ndUDSSendKey(TD1 *diagRef, uint8_t accessMode, 
	uint8_t keyIn[], int32_t len, LVBoolean *success);
/*!
 * ndUDSTesterPresent
 */
int32_t __cdecl ndUDSTesterPresent(TD1 *diagRef, LVBoolean *responseRequired, 
	LVBoolean *success);
/*!
 * ndUDSWriteDataByIdentifier
 */
int32_t __cdecl ndUDSWriteDataByIdentifier(TD1 *diagRef, uint16_t ID, 
	uint8_t dataIn[], int32_t len, LVBoolean *success);
/*!
 * ndUDSWriteMemoryByAddress
 */
int32_t __cdecl ndUDSWriteMemoryByAddress(TD1 *diagRef, uint32_t address, 
	uint8_t size, uint8_t dataIn[], int32_t len, LVBoolean *success);
/*!
 * ndWriteDataByLocalIdentifier
 */
int32_t __cdecl ndWriteDataByLocalIdentifier(TD1 *diagRef, uint8_t localID, 
	uint8_t dataIn[], int32_t len, LVBoolean *success);
/*!
 * ndWriteMemoryByAddress
 */
int32_t __cdecl ndWriteMemoryByAddress(TD1 *diagRef, uint32_t address, 
	uint8_t size, uint8_t dataIn[], int32_t len, LVBoolean *success);
/*!
 * ndSetProperty
 */
void __cdecl ndSetProperty(uint16_t propertyID, uint32_t propertyValue);
/*!
 * ndGetProperty
 */
uint32_t __cdecl ndGetProperty(uint16_t propertyID);
/*!
 * ndCreateExtendedCANIds
 */
void __cdecl ndCreateExtendedCANIds(uint16_t addressingMode, 
	uint16_t transportProtocol, uint8_t sourceAddress, uint8_t targetAddress, 
	uint32_t *transmitID, uint32_t *receiveID);
/*!
 * ndVWTPDisconnect
 */
int32_t __cdecl ndVWTPDisconnect(TD1 *diagRef);
/*!
 * ndVWTPConnect
 */
int32_t __cdecl ndVWTPConnect(TD1 *diagRef, uint32_t channelID, 
	uint8_t applicationType);
/*!
 * ndVWTPConnectionTest
 */
int32_t __cdecl ndVWTPConnectionTest(TD1 *diagRef);
/*!
 * ndClearDiagnosticInformation
 */
int32_t __cdecl ndClearDiagnosticInformation(TD1 *diagRef, 
	uint32_t groupOfDTC, TD3 *DTCDescriptor, LVBoolean *success);
/*!
 * ndControlDTCSetting
 */
int32_t __cdecl ndControlDTCSetting(TD1 *diagRef, uint32_t groupOfDTC, 
	uint8_t dataIn[], int32_t len, TD3 *DTCDescriptor, LVBoolean *success);
/*!
 * ndUDSClearDiagnosticInformation
 */
int32_t __cdecl ndUDSClearDiagnosticInformation(TD1 *diagRef, 
	uint32_t groupOfDTC, TD3 *DTCDescriptor, LVBoolean *success);
/*!
 * ndOBDOpen
 */
int32_t __cdecl ndOBDOpen(char CANInterface[], uint32_t baudrate, 
	uint32_t transmitID, uint32_t receiveID, TD1 *diagRefOut);
/*!
 * ndUDSRequestDownload
 */
int32_t __cdecl ndUDSRequestDownload(TD1 *diagRef, uint32_t memoryAddress, 
	uint32_t memorySize, uint8_t memoryAddressLength, uint8_t memorySizeLength, 
	uint8_t dataFormatIdentifier, uint32_t *blockSize, LVBoolean *success);
/*!
 * ndUDSRequestUpload
 */
int32_t __cdecl ndUDSRequestUpload(TD1 *diagRef, uint32_t memoryAddress, 
	uint32_t memorySize, uint8_t memoryAddressLength, uint8_t memorySizeLength, 
	uint8_t dataFormatIdentifier, uint32_t *blockSize, LVBoolean *success);
/*!
 * ndUDSTransferData
 */
int32_t __cdecl ndUDSTransferData(TD1 *diagRef, 
	uint8_t *blockSequenceCounter, uint8_t dataIn[], int32_t len, 
	uint8_t dataOut[], int32_t *len2, LVBoolean *success);
/*!
 * ndUDSRequestTransferExit
 */
int32_t __cdecl ndUDSRequestTransferExit(TD1 *diagRef, uint8_t dataIn[], 
	int32_t len, uint8_t dataOut[], int32_t *len2, LVBoolean *success);
/*!
 * ndUDS06WriteMemoryByAddress
 */
int32_t __cdecl ndUDS06WriteMemoryByAddress(TD1 *diagRef, uint8_t memAddrLen, 
	uint8_t memSizeLen, uint32_t address, uint32_t size, uint8_t dataIn[], 
	int32_t len, LVBoolean *success);
/*!
 * ndUDS06ReadMemoryByAddress
 */
int32_t __cdecl ndUDS06ReadMemoryByAddress(TD1 *diagRef, uint8_t memAddrLen, 
	uint8_t memSizeLen, uint32_t address, uint32_t size, uint8_t dataOut[], 
	int32_t *len, LVBoolean *success);
/*!
 * ndDiagFrameRecv
 */
int32_t __cdecl ndDiagFrameRecv(TD1 *diagRef, uint32_t timeout, 
	uint8_t dataOut[], int32_t *len);
/*!
 * ndDiagFrameSend
 */
int32_t __cdecl ndDiagFrameSend(TD1 *diagRef, uint8_t dataIn[], int32_t len);
/*!
 * ndDoIPActivateRouting
 */
int32_t __cdecl ndDoIPActivateRouting(TD1 *diagRef, uint8_t ActivationType, 
	uint16_t SourceAddress, uint16_t *TargetAddress);
/*!
 * ndDoIPConnect
 */
int32_t __cdecl ndDoIPConnect(TD1 *diagRef, char address[], 
	uint16_t SourceAddress, uint16_t TargetAddress);
/*!
 * ndDoIPDisconnect
 */
int32_t __cdecl ndDoIPDisconnect(TD1 *diagRef);
/*!
 * ndDoIPEntityStatus
 */
int32_t __cdecl ndDoIPEntityStatus(TD1 *diagRef, uint8_t *nodeType, 
	uint8_t *maxSockets, uint8_t *curSockets, LVBoolean *ok);
/*!
 * ndDoIPGetDiagPowerMode
 */
int32_t __cdecl ndDoIPGetDiagPowerMode(TD1 *diagRef, uint8_t *powerMode, 
	LVBoolean *ok);
/*!
 * ndDoIPSendVehicleIdentRequest
 */
int32_t __cdecl ndDoIPSendVehicleIdentRequest(TD1 *diagRef);
/*!
 * ndDoIPSendVehicleIdentReqEID
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqEID(TD1 *diagRef, char EID[]);
/*!
 * ndDoIPSendVehicleIdentReqVIN
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqVIN(TD1 *diagRef, char VIN[]);
/*!
 * ndDoIPGetEntities
 */
int32_t __cdecl ndDoIPGetEntities(TD1 *diagRef, uint16_t DoIPOpenType, 
	char VINOrEID[], uint8_t DoIPEntities[], int32_t *len);
/*!
 * ndOpenDiagnosticOnIP
 */
int32_t __cdecl ndOpenDiagnosticOnIP(LVBoolean *dynamicPort, 
	TD1 *DiagReferenceOut);
/*!
 * ndOpenDiagnosticOnLIN
 */
int32_t __cdecl ndOpenDiagnosticOnLIN(char LINInterface[], uint32_t baudrate, 
	uint8_t NAD, char MasterReqFrame[], char SlaveRespFrame[], TD1 *diagRefOut);
/*!
 * ndWWHOBDClearEmissionRelatedDTCs
 */
int32_t __cdecl ndWWHOBDClearEmissionRelatedDTCs(TD1 *diagRef, 
	LVBoolean *success);
/*!
 * ndWWHOBDConvertDTCsToJ1939
 */
int32_t __cdecl ndWWHOBDConvertDTCsToJ1939(TD4 DTCs[], int32_t lenDTCs, 
	TD5 DTCsJ1939[], int32_t *lenDTCsJ1939);
/*!
 * ndWWHOBDConvertDTCsToJ2012
 */
int32_t __cdecl ndWWHOBDConvertDTCsToJ2012(TD4 DTCs[], int32_t lenDTCs, 
	TD6 DTCsJ2012[], int32_t *lenDTCsJ2012);
/*!
 * ndWWHOBDRequestDID
 */
int32_t __cdecl ndWWHOBDRequestDID(TD1 *diagRef, uint16_t dataIdentifier, 
	uint8_t dataOut[], int32_t *len, LVBoolean *success);
/*!
 * ndWWHOBDRequestDTCExtendedDataRecord
 */
int32_t __cdecl ndWWHOBDRequestDTCExtendedDataRecord(TD1 *diagRef, 
	uint8_t DTCMaskRecord[], int32_t len, uint8_t dataOut[], int32_t *len2, 
	LVBoolean *success);
/*!
 * ndWWHOBDRequestEmissionRelatedDTCs
 */
int32_t __cdecl ndWWHOBDRequestEmissionRelatedDTCs(TD1 *diagRef, 
	uint8_t DTCSeverityMask, uint8_t DTCStatusMask, TD3 *DTCDescriptor, 
	uint8_t *severityAvailabilityMask, uint8_t *statusAvailabilityMask, 
	uint8_t *DTCFormatIdentifier, TD4 DTCs[], int32_t *len, LVBoolean *success);
/*!
 * ndWWHOBDRequestFreezeFrameInformation
 */
int32_t __cdecl ndWWHOBDRequestFreezeFrameInformation(TD1 *diagRef, 
	uint8_t DTCMaskRecord[], int32_t len, uint8_t DTCRecordNumber, 
	uint8_t dataOut[], int32_t *len2, LVBoolean *success);
/*!
 * ndWWHOBDRequestRID
 */
int32_t __cdecl ndWWHOBDRequestRID(TD1 *diagRef, uint8_t mode, 
	uint16_t routineIdentifier, uint8_t dataOut[], int32_t *len, 
	LVBoolean *success);
/*!
 * ndWWHOBDRequestSupportedDIDs
 */
int32_t __cdecl ndWWHOBDRequestSupportedDIDs(TD1 *diagRef, uint16_t DID, 
	uint16_t DIDsOut[], int32_t *len, LVBoolean *success);
/*!
 * ndWWHOBDRequestSupportedRIDs
 */
int32_t __cdecl ndWWHOBDRequestSupportedRIDs(TD1 *diagRef, 
	uint16_t RIDsOut[], int32_t *len, LVBoolean *success);
/*!
 * ndGetTimeStamp
 */
int32_t __cdecl ndGetTimeStamp(TD1 *diagRef, uint64_t *timeStampWriteFirst, 
	uint64_t *timeStampWriteLast, uint64_t *timeStampReadFirst, 
	uint64_t *timeStampReadLast);
/*!
 * ndGetHandleSize
 */
int32_t __cdecl ndGetHandleSize(void);
/*!
 * ndDoIPGetEntitiesEx
 */
int32_t __cdecl ndDoIPGetEntitiesEx(TD1 *diagRef, char BroadcastAddress[], 
	uint16_t DoIPOpenType, char VINOrEID[], uint8_t DoIPEntities[], int32_t *len);
/*!
 * ndDoIPSendVehicleIdentReqEIDEx
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqEIDEx(TD1 *diagRef, 
	char BroadcastAddress[], char EID[]);
/*!
 * ndDoIPSendVehicleIdentRequestEx
 */
int32_t __cdecl ndDoIPSendVehicleIdentRequestEx(TD1 *diagRef, 
	char BroadcastAddress[]);
/*!
 * ndDoIPSendVehicleIdentReqVINEx
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqVINEx(TD1 *diagRef, 
	char BroadcastAddress[], char VIN[]);
/*!
 * ndDiagGetProperty
 */
int32_t __cdecl ndDiagGetProperty(TD1 *diagRef, uint16_t propertyID, 
	uint32_t *propertyValue);
/*!
 * ndDiagSetProperty
 */
int32_t __cdecl ndDiagSetProperty(TD1 *diagRef, uint16_t propertyID, 
	uint32_t propertyValue);
/*!
 * ndOBDOpenOnCANFD
 */
int32_t __cdecl ndOBDOpenOnCANFD(char CANInterface[], uint32_t baudrate, 
	uint64_t FDBaudrate, uint32_t ioMode, uint16_t maxDLC, uint32_t transmitID, 
	uint32_t receiveID, TD1 *diagRefOut);
/*!
 * ndOpenDiagnosticOnCANFD
 */
int32_t __cdecl ndOpenDiagnosticOnCANFD(char CANInterface[], 
	uint64_t baudrate, uint64_t FDBaudrate, uint32_t ioMode, 
	uint16_t transportProtocol, uint16_t maxDLC, uint32_t transmitID, 
	uint32_t receiveID, TD1 *diagRefOut);
/*!
 * ndOpenDiagnosticOnIPVersion
 */
int32_t __cdecl ndOpenDiagnosticOnIPVersion(LVBoolean *dynamicPort, 
	uint8_t DoIPProtocolVersion, TD1 *DiagRefOut);
/*!
 * ndStartPeriodicTesterPresent
 */
int32_t __cdecl ndStartPeriodicTesterPresent(TD1 *diagRef, 
	uint32_t messageType, double periodSec, int32_t responseRequired, 
	uint8_t userMessage[], int32_t len);
/*!
 * ndStopPeriodicTesterPresent
 */
int32_t __cdecl ndStopPeriodicTesterPresent(TD1 *diagRef);
/*!
 * ndDoIPSendVehicleIdentReqEIDAllVersions
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqEIDAllVersions(TD1 *diagRef, 
	char BroadcastAddress[], LVBoolean *AllVersions, char EID[]);
/*!
 * ndDoIPSendVehicleIdentRequestAllVersions
 */
int32_t __cdecl ndDoIPSendVehicleIdentRequestAllVersions(TD1 *diagRef, 
	char BroadcastAddress[], LVBoolean *AllVersions);
/*!
 * ndDoIPSendVehicleIdentReqVINAllVersions
 */
int32_t __cdecl ndDoIPSendVehicleIdentReqVINAllVersions(TD1 *diagRef, 
	char BroadcastAddress[], LVBoolean *AllVersions, char VIN[]);
/*!
 * ndDoIPGetEntitiesAllVersions
 */
int32_t __cdecl ndDoIPGetEntitiesAllVersions(TD1 *diagRef, 
	char BroadcastAddress[], LVBoolean *AllVersions, uint16_t DoIPOpenType, 
	char VINOrEID[], uint8_t DoIPEntities[], int32_t *len);
/*!
 * ndDoIPConnectVersion
 */
int32_t __cdecl ndDoIPConnectVersion(TD1 *diagRef, char address[], 
	uint16_t SourceAddress, uint16_t TargetAddress, uint8_t ProtocolVersion);
/*!
 * ndOpenDiagnosticOnIPStack
 */
int32_t __cdecl ndOpenDiagnosticOnIPStack(LVBoolean *dynamicPort, 
	uint8_t DoIPProtocolVersion, char xnetStackName[], char xnetLocalInterface[], 
	TD1 *DiagRefOut);
/*!
 * ndDoIPConnectPorts
 */
int32_t __cdecl ndDoIPConnectPorts(TD1 *diagRef, char address[], 
	uint16_t SourceAddress, uint16_t TargetAddress, uint8_t protocolVersion, 
	uint16_t localPort, uint16_t remotePort);
/*!
 * ndOpenDiagnosticOnIPPort
 */
int32_t __cdecl ndOpenDiagnosticOnIPPort(LVBoolean *dynamicPort, 
	uint8_t DoIPProtocolVersion, char xnetStackName[], char xnetLocalInterface[], 
	uint16_t localStaticPort, TD1 *DiagRefOut);

MgErr __cdecl LVDLLStatus(char *errStr, int errStrLen, void *module);

void __cdecl SetExecuteVIsInPrivateExecutionSystem(Bool32 value);

#ifdef __cplusplus
} // extern "C"
#endif

#endif /* NIDIAGCS_H */

